# portune

Multitreaded port scanner

# features

* parallel check of port availability against server/ports
* console output result / summary
* html full report / dns domain summary / vlan timeout summary
* mail with html summary / report attachment (mailhost relay)

